@@ -1,7 +1,11 @@
 {-# LANGUAGE CPP #-}
 {-# LANGUAGE PatternGuards #-}
 #ifdef TRUSTWORTHY
+# if MIN_VERSION_template_haskell(2,12,0)
+{-# LANGUAGE Safe #-}
+# else
 {-# LANGUAGE Trustworthy #-}
+# endif
 #endif
 
 #ifndef MIN_VERSION_base
@@ -28,6 +32,7 @@ module Control.Lens.TH
     makeLenses, makeLensesFor
   , makeClassy, makeClassyFor, makeClassy_
   , makeFields
+  , makeFieldsNoPrefix
   -- ** Prisms
   , makePrisms
   , makeClassyPrisms
@@ -55,6 +60,7 @@ module Control.Lens.TH
   , classyRules_
   , defaultFieldRules
   , camelCaseFields
+  , classUnderscoreNoPrefixFields
   , underscoreFields
   , abbreviatedFields
   -- ** LensRules configuration accessors
@@ -73,6 +79,7 @@ module Control.Lens.TH
   , lookingupNamer
   , mappingNamer
   , camelCaseNamer
+  , classUnderscoreNoPrefixNamer
   , underscoreNamer
   , abbreviatedNamer
   ) where
@@ -83,7 +90,8 @@ import Control.Applicative
 #if !(MIN_VERSION_template_haskell(2,7,0))
 import Control.Monad (ap)
 #endif
-import qualified Control.Monad.Trans as Trans
+import Control.Monad.Trans.Class
+import Control.Monad.Trans.State
 import Control.Monad.Trans.Writer
 import Control.Lens.Fold
 import Control.Lens.Getter
@@ -96,7 +104,7 @@ import Control.Lens.Internal.FieldTH
 import Control.Lens.Internal.PrismTH
 import Control.Lens.Wrapped () -- haddocks
 import Control.Lens.Type () -- haddocks
-import Data.Char (toLower, isUpper)
+import Data.Char (toLower, toUpper, isUpper)
 import Data.Foldable hiding (concat, any)
 import Data.List as List
 import qualified Data.Map as Map
@@ -109,7 +117,7 @@ import Data.Set.Lens
 import Data.Traversable hiding (mapM)
 import Language.Haskell.TH
 import Language.Haskell.TH.Lens
-import Language.Haskell.TH.Syntax
+import Language.Haskell.TH.Syntax hiding (lift)
 
 #ifdef HLINT
 {-# ANN module "HLint: ignore Eta reduce" #-}
@@ -178,25 +186,10 @@ createClass f r =
 lensField :: Lens' LensRules FieldNamer
 lensField f r = fmap (\x -> r { _fieldToDef = x}) (f (_fieldToDef r))
 
--- | The rule to create function names of lenses for data fields.
---
--- Although it's sometimes useful, you won't need the first two
--- arguments most of the time.
-type FieldNamer = Name -- ^ Name of the data type that lenses are being generated for.
-                  -> [Name] -- ^ Names of all fields (including the field being named) in the data type.
-                  -> Name -- ^ Name of the field being named.
-                  -> [DefName] -- ^ Name(s) of the lens functions. If empty, no lens is created for that field.
-
 -- | 'Lens'' to access the option for naming "classy" lenses.
 lensClass :: Lens' LensRules ClassyNamer
 lensClass f r = fmap (\x -> r { _classyLenses = x }) (f (_classyLenses r))
 
--- | The optional rule to create a class and method around a
--- monomorphic data type. If this naming convention is provided, it
--- generates a "classy" lens.
-type ClassyNamer = Name -- ^ Name of the data type that lenses are being generated for.
-                   -> Maybe (Name, Name) -- ^ Names of the class and the main method it generates, respectively.
-
 -- | Rules for making fairly simple partial lenses, ignoring the special cases
 -- for isomorphisms and traversals, and not making any classes.
 -- It uses 'underscoreNoPrefixNamer'.
@@ -457,13 +450,13 @@ declareClassyFor classes fields
 -- @
 declarePrisms :: DecsQ -> DecsQ
 declarePrisms = declareWith $ \dec -> do
-  emit =<< Trans.lift (makeDecPrisms True dec)
+  emit =<< liftDeclare (makeDecPrisms True dec)
   return dec
 
 -- | Build 'Control.Lens.Wrapped.Wrapped' instance for each newtype.
 declareWrapped :: DecsQ -> DecsQ
 declareWrapped = declareWith $ \dec -> do
-  maybeDecs <- Trans.lift (makeWrappedForDec dec)
+  maybeDecs <- liftDeclare (makeWrappedForDec dec)
   forM_ maybeDecs emit
   return dec
 
@@ -476,7 +469,7 @@ declareFields = declareLensesWith defaultFieldRules
 -- off.
 declareLensesWith :: LensRules -> DecsQ -> DecsQ
 declareLensesWith rules = declareWith $ \dec -> do
-  emit =<< Trans.lift (makeFieldOpticsForDec rules dec)
+  emit =<< lift (makeFieldOpticsForDec' rules dec)
   return $ stripFields dec
 
 -----------------------------------------------------------------------------
@@ -688,6 +681,24 @@ camelCaseNamer tyName fields field = maybeToList $ do
   computeMethod (x:xs) | isUpper x = Just (toLower x : xs)
   computeMethod _                  = Nothing
 
+-- | Field rules for fields in the form @ _fieldname @ (the leading
+-- underscore is mandatory).
+--
+-- __Note__: The primary difference to 'camelCaseFields' is that for
+-- @classUnderscoreNoPrefixFields@ the field names are not expected to
+-- be prefixed with the type name. This might be the desired behaviour
+-- when the @DuplicateRecordFields@ extension is enabled.
+classUnderscoreNoPrefixFields :: LensRules
+classUnderscoreNoPrefixFields =
+  defaultFieldRules & lensField .~ classUnderscoreNoPrefixNamer
+
+-- | A 'FieldNamer' for 'classUnderscoreNoPrefixFields'.
+classUnderscoreNoPrefixNamer :: FieldNamer
+classUnderscoreNoPrefixNamer _ _ field = maybeToList $ do
+  fieldUnprefixed <- stripPrefix "_" (nameBase field)
+  let className  = "Has" ++ overHead toUpper fieldUnprefixed
+      methodName = fieldUnprefixed
+  return (MethodName (mkName className) (mkName methodName))
 
 -- | Field rules fields in the form @ prefixFieldname or _prefixFieldname @
 -- If you want all fields to be lensed, then there is no reason to use an @_@ before the prefix.
@@ -725,7 +736,7 @@ abbreviatedNamer _ fields field = maybeToList $ do
 -- /e.g/
 --
 -- @
--- data Foo a = Foo { _fooX :: 'Int', _fooY : a }
+-- data Foo a = Foo { _fooX :: 'Int', _fooY :: a }
 -- newtype Bar = Bar { _barX :: 'Char' }
 -- makeFields ''Foo
 -- makeFields ''Bar
@@ -757,6 +768,48 @@ abbreviatedNamer _ fields field = maybeToList $ do
 makeFields :: Name -> DecsQ
 makeFields = makeFieldOptics camelCaseFields
 
+-- | Generate overloaded field accessors based on field names which
+-- are only prefixed with an underscore (e.g. '_name'), not
+-- additionally with the type name (e.g. '_fooName').
+--
+-- This might be the desired behaviour in case the
+-- @DuplicateRecordFields@ language extension is used in order to get
+-- rid of the necessity to prefix each field name with the type name.
+--
+-- As an example:
+--
+-- @
+-- data Foo a  = Foo { _x :: 'Int', _y :: a }
+-- newtype Bar = Bar { _x :: 'Char' }
+-- makeFieldsNoPrefix ''Foo
+-- makeFieldsNoPrefix ''Bar
+-- @
+--
+-- will create classes
+--
+-- @
+-- class HasX s a | s -> a where
+--   x :: Lens' s a
+-- class HasY s a | s -> a where
+--   y :: Lens' s a
+-- @
+--
+-- together with instances
+--
+-- @
+-- instance HasX (Foo a) Int
+-- instance HasY (Foo a) a where
+-- instance HasX Bar Char where
+-- @
+--
+-- For details, see 'classUnderscoreNoPrefixFields'.
+--
+-- @
+-- makeFieldsNoPrefix = 'makeLensesWith' 'classUnderscoreNoPrefixFields'
+-- @
+makeFieldsNoPrefix :: Name -> DecsQ
+makeFieldsNoPrefix = makeFieldOptics classUnderscoreNoPrefixFields
+
 defaultFieldRules :: LensRules
 defaultFieldRules = LensRules
   { _simpleLenses    = True
@@ -775,12 +828,19 @@ defaultFieldRules = LensRules
 declareWith :: (Dec -> Declare Dec) -> DecsQ -> DecsQ
 declareWith fun = (runDeclare . traverseDataAndNewtype fun =<<)
 
--- | Monad for emitting top-level declarations as a side effect.
-type Declare = WriterT (Endo [Dec]) Q
+-- | Monad for emitting top-level declarations as a side effect. We also track
+-- the set of field class 'Name's that have been created and consult them to
+-- avoid creating duplicate classes.
+
+-- See #463 for more information.
+type Declare = WriterT (Endo [Dec]) (StateT (Set Name) Q)
+
+liftDeclare :: Q a -> Declare a
+liftDeclare = lift . lift
 
 runDeclare :: Declare [Dec] -> DecsQ
 runDeclare dec = do
-  (out, endo) <- runWriterT dec
+  (out, endo) <- evalStateT (runWriterT dec) Set.empty
   return $ out ++ appEndo endo []
 
 emit :: [Dec] -> Declare ()
